@@ -14,7 +14,7 @@
 #
 #  This file is part of the 'rstudio/gt' project.
 #
-#  Copyright (c) 2018-2025 gt authors
+#  Copyright (c) 2018-2026 gt authors
 #
 #  For full copyright and license information, please look at
 #  https://gt.rstudio.com/LICENSE.html
@@ -840,6 +840,7 @@ set_style.cells_body <- function(loc, data, style) {
 set_style.cells_stub <- function(loc, data, style) {
 
   call <- call("cells_stub")
+
   resolved <- resolve_cells_stub(data = data, object = loc, call = call)
 
   columns <- resolved$columns
@@ -847,13 +848,20 @@ set_style.cells_stub <- function(loc, data, style) {
 
   # Get all stub variables for reference
   stub_vars <- dt_boxhead_get_var_stub(data = data)
-  
-  # Check if this is traditional usage (no columns parameter) 
+
+  # Check if this is traditional usage (no columns parameter)
   # vs. new usage (explicit columns parameter provided)
+
   is_traditional_usage <- is.null(loc$columns)
-  
-  if (is_traditional_usage) {
-    # For backward compatibility: traditional cells_stub() usage without columns parameter
+
+  # For multi-column stubs, we need to apply styles to all stub columns
+
+  # even in traditional usage mode (when columns = NULL means "all columns")
+  has_multicolumn_stub <- length(stub_vars) > 1 && !all(is.na(stub_vars))
+
+  if (is_traditional_usage && !has_multicolumn_stub) {
+    # For backward compatibility with single-column stubs: traditional
+    # cells_stub() usage without columns parameter
     # Use the original "stub" locname for compatibility with existing code
     data <-
       dt_styles_add(
@@ -867,13 +875,14 @@ set_style.cells_stub <- function(loc, data, style) {
       )
   } else {
     # New usage: per-column stub styling
-    # If no stub columns are resolved, apply to all stub columns (backward compatibility)
+    # If no stub columns are resolved (traditional usage with multi-column stub,
+    # or columns = NULL was explicitly provided), apply to all stub columns
     if (length(columns) == 0) {
       if (!all(is.na(stub_vars))) {
         columns <- stub_vars
       }
     }
-    
+
     # Apply styling to each specified stub column using stub_column locname
     for (col in columns) {
       data <-
